@@ -2,6 +2,7 @@ package login
 
 import (
 	"bytes"
+	"context"
 	"encoding/json"
 	"fmt"
 	"io"
@@ -13,7 +14,7 @@ import (
 	"strings"
 
 	"github.com/spf13/cobra"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 
 	corev1 "k8s.io/api/core/v1"
 	kerrors "k8s.io/apimachinery/pkg/api/errors"
@@ -43,30 +44,29 @@ var (
 
 		As an advanced option you may specify the credentials to login with using --auth-basic
 		with USER:PASSWORD. This may not be used with the -z flag.
-		
-		You may specify an alternate file to write credentials to with --to instead of 
-		.docker/config.json in your home directory. If you pass --to=- the file will be 
+
+		You may specify an alternate file to write credentials to with --to instead of
+		.docker/config.json in your home directory. If you pass --to=- the file will be
 		written to standard output.
 
 		To detect the registry hostname the client will attempt to find an image stream in
 		the current namespace or the openshift namespace and use the status fields that
 		indicate the registry hostnames. If no image stream is found or if you do not have
-		permission to view image streams you will have to pass the --registry flag with the 
+		permission to view image streams you will have to pass the --registry flag with the
 		desired hostname.
 
 		Experimental: This command is under active development and may change without notice.`)
 
 	example = templates.Examples(`
-# Log in to the integrated registry
-%[1]s
+		# Log in to the integrated registry
+		oc registry login
 
-# Log in as the default service account in the current namespace
-%[1]s -z default
+		# Log in as the default service account in the current namespace
+		oc registry login -z default
 
-# Log in to a different registry using BASIC auth credentials
-%[1]s --registry quay.io --auth-basic=USER:PASS
-
-`)
+		# Log in to a different registry using BASIC auth credentials
+		oc registry login --registry quay.io --auth-basic=USER:PASS
+	`)
 )
 
 type Credentials struct {
@@ -108,14 +108,14 @@ func NewRegistryLoginOptions(streams genericclioptions.IOStreams) *LoginOptions
 }
 
 // New logs you in to a container image registry locally.
-func NewRegistryLoginCmd(name string, f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
+func NewRegistryLoginCmd(f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
 	o := NewRegistryLoginOptions(streams)
 
 	cmd := &cobra.Command{
 		Use:     "login ",
 		Short:   "Login to the integrated registry",
 		Long:    desc,
-		Example: fmt.Sprintf(example, name+" login"),
+		Example: example,
 		Run: func(c *cobra.Command, args []string) {
 			kcmdutil.CheckErr(o.Complete(f, args))
 			kcmdutil.CheckErr(o.Validate())
@@ -162,7 +162,7 @@ func (o *LoginOptions) Complete(f kcmdutil.Factory, args []string) error {
 		if err != nil {
 			return err
 		}
-		sa, err := client.CoreV1().ServiceAccounts(ns).Get(o.ServiceAccount, metav1.GetOptions{})
+		sa, err := client.CoreV1().ServiceAccounts(ns).Get(context.TODO(), o.ServiceAccount, metav1.GetOptions{})
 		if err != nil {
 			if kerrors.IsNotFound(err) {
 				return fmt.Errorf("the service account %s does not exist in namespace %s", o.ServiceAccount, ns)
@@ -171,7 +171,7 @@ func (o *LoginOptions) Complete(f kcmdutil.Factory, args []string) error {
 		}
 		var lastErr error
 		for _, ref := range sa.Secrets {
-			secret, err := client.CoreV1().Secrets(ns).Get(ref.Name, metav1.GetOptions{})
+			secret, err := client.CoreV1().Secrets(ns).Get(context.TODO(), ref.Name, metav1.GetOptions{})
 			if err != nil {
 				lastErr = err
 				continue
@@ -245,7 +245,7 @@ func (o *LoginOptions) Complete(f kcmdutil.Factory, args []string) error {
 
 func findPublicHostname(client *imageclient.Clientset, namespaces ...string) (name string, internal bool, err error) {
 	for _, ns := range namespaces {
-		imageStreams, err := client.ImageV1().ImageStreams(ns).List(metav1.ListOptions{})
+		imageStreams, err := client.ImageV1().ImageStreams(ns).List(context.TODO(), metav1.ListOptions{})
 		if kerrors.IsUnauthorized(err) {
 			return "", false, err
 		}
